﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using SampleGridDropDown;
using SampleGridDropDown.ViewModels;
using System.Collections;
using Syncfusion.JavaScript.DataSources;

namespace SampleGridDropDown.Controllers
{
    public class GridController : Controller
    {
        //
        // GET: /Grid/
        public ActionResult GridFeatures()
        {
            ViewBag.dataSource = LocalData.Users();
            ViewData["departmentDataSource"] = LocalData.Departments();
            return View();
        }

        public ActionResult ManageUsers()
        {
            ViewBag.dataSource = LocalData.Users();
            ViewData["departmentDataSource"] = LocalData.Departments();
            return View();
        }

        public ActionResult BatchUserDataSource(Syncfusion.JavaScript.DataManager dm)
        {
            IList<UserViewModel> list = LocalData.Users();
            return BatchDataSource(dm, list, list.Count);
        }

        private ActionResult BatchDataSource(Syncfusion.JavaScript.DataManager dm,
            object dataSource, int dataSourceCount)
        {
            ViewBag.dataSource = dataSource;
            IEnumerable DataSource = ViewBag.dataSource;
            BatchDataResult result = new BatchDataResult();
            DataOperations obj = new DataOperations();
            if (dm.Skip != 0)
            {
                DataSource = obj.PerformSkip(DataSource, dm.Skip);
            }
            if (dm.Take != 0)
            {
                DataSource = obj.PerformTake(DataSource, dm.Take);
            }
            result.result = DataSource;
            result.count = dataSourceCount;
            //result.count = manager.AdminData.ActiveAssessors().Count;
            return Json(result, JsonRequestBehavior.AllowGet);
        }

        public ActionResult BatchUsersUpdate(List<UserViewModel> changed,
           List<UserViewModel> added, List<UserViewModel> deleted)
        {
            if (changed != null)
            {
                LocalData.Update(changed);
            }
            //if (deleted != null)
            //    OrderRepository.Delete(deleted);
            if (added != null)
                LocalData.Add(added);
            var data = LocalData.Users();
            return Json(data, JsonRequestBehavior.AllowGet);
        }
    }

    public class LocalData
    {
        private static List<UserViewModel> _users;

        private static List<DepartmentViewModelcs> _departments;

        static LocalData()
        {
            _departments = new List<DepartmentViewModelcs>();
            _departments.Add(new DepartmentViewModelcs()
            {
                Id = Guid.NewGuid().ToString(),
                DepartmentName = "Sales"
            });
            _departments.Add(new DepartmentViewModelcs()
            {
                Id = Guid.NewGuid().ToString(),
                DepartmentName = "Marketing"
            });
            _departments.Add(new DepartmentViewModelcs()
            {
                Id = Guid.NewGuid().ToString(),
                DepartmentName = "Finanance"
            });

            _users = new List<UserViewModel>();

            var firstUser = new UserViewModel()
            {
                Id = Guid.NewGuid().ToString(),
                FirstName = "User One",
                LastName = "Last Name",
                
            };

            firstUser.DepartmentList.Add(_departments[0]);

            _users.Add(firstUser);
        }

        public static IList<UserViewModel> Users()
        {
            return _users;
        }

        public static IList<DepartmentViewModelcs> Departments()
        {
            return _departments;
        }

        internal static void Add(List<UserViewModel> added)
        {
            _users.AddRange(added);
        }

        internal static void Update(List<UserViewModel> changed)
        {
            foreach (UserViewModel vm in changed)
            {
                var current = _users.SingleOrDefault(t => t.Id.Equals(vm.Id, StringComparison.OrdinalIgnoreCase));
                if (current != null)
                {
                    var index = _users.IndexOf(current);
                    if (index > -1)
                        _users[index] = vm;
                }
            }
        }
    }

    public class BatchDataResult
    {
        public IEnumerable result { get; set; }
        public int count { get; set; }
    }
}
